@@ -2,7 +2,7 @@
 """
 <name>NMF</name>
 <description>Non negative matrix factorization</description>
-<icon>icons/NMF.png</icon>
+<icon>icons/NMFicon.png</icon>
 <priority>30</priority>
 """
 
@@ -97,7 +97,7 @@ class OWNMF(OWWidget):
         button = OWGUI.button(rfbox, self, '...', callback = self.browseFile, disabled=0)
         button.setIcon(self.style().standardIcon(QStyle.SP_DirOpenIcon))
         button.setSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed)
-        self.resend = OWGUI.button(self.saveBox, self, "Retreive data", callback = self.resendData, default=True)
+        self.resend = OWGUI.button(self.saveBox, self, "Retrieve data", callback = self.resendData, default=True)
         
         OWGUI.rubber(self.controlArea)
         self.setFilelist()
